@@ -4,13 +4,14 @@ import (
 	"fmt"
 
 	"github.com/jesseduffield/lazygit/pkg/utils"
+	"github.com/samber/lo"
 	"github.com/stefanhaller/git-todo-parser/todo"
 )
 
 // Special commit hash for empty tree object
 const EmptyTreeCommitHash = "4b825dc642cb6eb9a060e54bf8d69288fbee4904"
 
-type CommitStatus int
+type CommitStatus uint8
 
 const (
 	StatusNone CommitStatus = iota
@@ -18,7 +19,8 @@ const (
 	StatusPushed
 	StatusMerged
 	StatusRebasing
-	StatusSelected
+	StatusCherryPickingOrReverting
+	StatusConflicted
 	StatusReflog
 )
 
@@ -26,11 +28,9 @@ const (
 	// Conveniently for us, the todo package starts the enum at 1, and given
 	// that it doesn't have a "none" value, we're setting ours to 0
 	ActionNone todo.TodoCommand = 0
-	// "Comment" is the last one of the todo package's enum entries
-	ActionConflict = todo.Comment + 1
 )
 
-type Divergence int
+type Divergence uint8
 
 // For a divergence log (left/right comparison of two refs) this is set to
 // either DivergenceLeft or DivergenceRight for each commit; for normal
@@ -43,35 +43,78 @@ const (
 
 // Commit : A git commit
 type Commit struct {
-	Hash          string
+	hash          *string
 	Name          string
-	Status        CommitStatus
-	Action        todo.TodoCommand
 	Tags          []string
 	ExtraInfo     string // something like 'HEAD -> master, tag: v0.15.2'
 	AuthorName    string // something like 'Jesse Duffield'
 	AuthorEmail   string // something like 'jessedduffield@gmail.com'
 	UnixTimestamp int64
-	Divergence    Divergence // set to DivergenceNone unless we are showing the divergence view
 
 	// Hashes of parent commits (will be multiple if it's a merge commit)
-	Parents []string
+	parents []*string
+
+	// When filtering by path, this contains the paths that were changed in this
+	// commit; nil when not filtering by path.
+	FilterPaths []string
+
+	Status     CommitStatus
+	Action     todo.TodoCommand
+	Divergence Divergence // set to DivergenceNone unless we are showing the divergence view
+}
+
+type NewCommitOpts struct {
+	Hash          string
+	Name          string
+	Status        CommitStatus
+	Action        todo.TodoCommand
+	Tags          []string
+	ExtraInfo     string
+	AuthorName    string
+	AuthorEmail   string
+	UnixTimestamp int64
+	Divergence    Divergence
+	Parents       []string
+}
+
+func NewCommit(hashPool *utils.StringPool, opts NewCommitOpts) *Commit {
+	return &Commit{
+		hash:          hashPool.Add(opts.Hash),
+		Name:          opts.Name,
+		Status:        opts.Status,
+		Action:        opts.Action,
+		Tags:          opts.Tags,
+		ExtraInfo:     opts.ExtraInfo,
+		AuthorName:    opts.AuthorName,
+		AuthorEmail:   opts.AuthorEmail,
+		UnixTimestamp: opts.UnixTimestamp,
+		Divergence:    opts.Divergence,
+		parents:       lo.Map(opts.Parents, func(s string, _ int) *string { return hashPool.Add(s) }),
+	}
+}
+
+func (c *Commit) Hash() string {
+	return *c.hash
+}
+
+func (c *Commit) HashPtr() *string {
+	return c.hash
 }
 
 func (c *Commit) ShortHash() string {
-	return utils.ShortHash(c.Hash)
+	return utils.ShortHash(c.Hash())
 }
 
 func (c *Commit) FullRefName() string {
-	return c.Hash
+	return c.Hash()
 }
 
 func (c *Commit) RefName() string {
-	return c.Hash
+	return c.Hash()
 }
 
 func (c *Commit) ShortRefName() string {
-	return c.Hash[:7]
+	return c.Hash()[:7]
 }
 
 func (c *Commit) ParentRefName() string {
@@ -81,8 +124,16 @@ func (c *Commit) ParentRefName() string {
 	return c.RefName() + "^"
 }
 
+func (c *Commit) Parents() []string {
+	return lo.Map(c.parents, func(s *string, _ int) string { return *s })
+}
+
+func (c *Commit) ParentPtrs() []*string {
+	return c.parents
+}
+
 func (c *Commit) IsFirstCommit() bool {
-	return len(c.Parents) == 0
+	return len(c.parents) == 0
 }
 
 func (c *Commit) ID() string {
@@ -90,11 +141,11 @@ func (c *Commit) ID() string {
 }
 
 func (c *Commit) Description() string {
-	return fmt.Sprintf("%s %s", c.Hash[:7], c.Name)
+	return fmt.Sprintf("%s %s", c.Hash()[:7], c.Name)
 }
 
 func (c *Commit) IsMerge() bool {
-	return len(c.Parents) > 1
+	return len(c.parents) > 1
 }
 
 // returns true if this commit is not actually in the git log but instead
