@@ -31,6 +31,15 @@ func NewRefsHelper(
 	}
 }
 
+func (self *RefsHelper) SelectFirstBranchAndFirstCommit() {
+	self.c.Contexts().Branches.SetSelection(0)
+	self.c.Contexts().ReflogCommits.SetSelection(0)
+	self.c.Contexts().LocalCommits.SetSelection(0)
+	self.c.Contexts().Branches.GetView().SetOriginY(0)
+	self.c.Contexts().ReflogCommits.GetView().SetOriginY(0)
+	self.c.Contexts().LocalCommits.GetView().SetOriginY(0)
+}
+
 func (self *RefsHelper) CheckoutRef(ref string, options types.CheckoutRefOptions) error {
 	waitingStatus := options.WaitingStatus
 	if waitingStatus == "" {
@@ -40,9 +49,8 @@ func (self *RefsHelper) CheckoutRef(ref string, options types.CheckoutRefOptions
 	cmdOptions := git_commands.CheckoutOptions{Force: false, EnvVars: options.EnvVars}
 
 	refresh := func() {
-		self.c.Contexts().Branches.SetSelection(0)
-		self.c.Contexts().ReflogCommits.SetSelection(0)
-		self.c.Contexts().LocalCommits.SetSelection(0)
+		self.SelectFirstBranchAndFirstCommit()
+
 		// loading a heap of commits is slow so we limit them whenever doing a reset
 		self.c.Contexts().LocalCommits.SetLimitCommits(true)
 
@@ -61,6 +69,10 @@ func (self *RefsHelper) CheckoutRef(ref string, options types.CheckoutRefOptions
 		return self.c.WithWaitingStatus(waitingStatus, f)
 	}
 
+	// Switch to the branches context _before_ starting to check out the branch, so that we see the
+	// inline status. This is a no-op if the branches panel is already focused.
+	self.c.Context().Push(self.c.Contexts().Branches, types.OnFocusOpts{})
+
 	return withCheckoutStatus(func(gocui.Task) error {
 		if err := self.c.Git().Branch.Checkout(ref, cmdOptions); err != nil {
 			// note, this will only work for english-language git commands. If we force git to use english, and the error isn't this one, then the user will receive an english command they may not understand. I'm not sure what the best solution to this is. Running the command once in english and a second time in the native language is one option
@@ -109,11 +121,6 @@ func (self *RefsHelper) CheckoutRef(ref string, options types.CheckoutRefOptions
 // Shows a prompt to choose between creating a new branch or checking out a detached head
 func (self *RefsHelper) CheckoutRemoteBranch(fullBranchName string, localBranchName string) error {
 	checkout := func(branchName string) error {
-		// Switch to the branches context _before_ starting to check out the
-		// branch, so that we see the inline status
-		if self.c.Context().Current() != self.c.Contexts().Branches {
-			self.c.Context().Push(self.c.Contexts().Branches, types.OnFocusOpts{})
-		}
 		return self.CheckoutRef(branchName, types.CheckoutRefOptions{})
 	}
 
@@ -349,8 +356,7 @@ func (self *RefsHelper) NewBranch(from string, fromFormattedName string, suggest
 			self.c.Context().Push(self.c.Contexts().Branches, types.OnFocusOpts{})
 		}
 
-		self.c.Contexts().LocalCommits.SetSelection(0)
-		self.c.Contexts().Branches.SetSelection(0)
+		self.SelectFirstBranchAndFirstCommit()
 
 		self.c.Refresh(types.RefreshOptions{Mode: types.BLOCK_UI, KeepBranchSelectionIndex: true})
 	}
@@ -505,8 +511,7 @@ func (self *RefsHelper) moveCommitsToNewBranchStackedOnCurrentBranch(newBranchNa
 		}
 	}
 
-	self.c.Contexts().LocalCommits.SetSelection(0)
-	self.c.Contexts().Branches.SetSelection(0)
+	self.SelectFirstBranchAndFirstCommit()
 
 	self.c.Refresh(types.RefreshOptions{Mode: types.BLOCK_UI, KeepBranchSelectionIndex: true})
 	return nil
@@ -544,8 +549,7 @@ func (self *RefsHelper) moveCommitsToNewBranchOffOfMainBranch(newBranchName stri
 		}
 	}
 
-	self.c.Contexts().LocalCommits.SetSelection(0)
-	self.c.Contexts().Branches.SetSelection(0)
+	self.SelectFirstBranchAndFirstCommit()
 
 	self.c.Refresh(types.RefreshOptions{Mode: types.BLOCK_UI, KeepBranchSelectionIndex: true})
 	return nil
