@@ -869,7 +869,7 @@ func (self *LocalCommitsController) revert(commits []*models.Commit, start, end
 					return err
 				}
 				self.context().MoveSelection(len(commits))
-				self.context().FocusLine()
+				self.context().HandleFocus(types.OnFocusOpts{ScrollSelectionIntoView: true})
 
 				if mustStash {
 					if err := self.c.Git().Stash.Pop(0); err != nil {
@@ -1116,8 +1116,8 @@ func isFixupCommit(subject string) (string, bool) {
 	prefixes := []string{"fixup! ", "squash! ", "amend! "}
 	trimPrefix := func(s string) (string, bool) {
 		for _, prefix := range prefixes {
-			if strings.HasPrefix(s, prefix) {
-				return strings.TrimPrefix(s, prefix), true
+			if trimmedSubject, ok := strings.CutPrefix(s, prefix); ok {
+				return trimmedSubject, true
 			}
 		}
 		return s, false
