@@ -4,6 +4,7 @@ import (
 	"github.com/jesseduffield/gocui"
 	"github.com/jesseduffield/lazygit/pkg/config"
 	"github.com/jesseduffield/lazygit/pkg/gui/patch_exploring"
+	"github.com/jesseduffield/lazygit/pkg/i18n"
 	"github.com/jesseduffield/lazygit/pkg/utils"
 	"github.com/sasha-s/go-deadlock"
 )
@@ -108,7 +109,7 @@ type Context interface {
 
 	HandleFocus(opts OnFocusOpts)
 	HandleFocusLost(opts OnFocusLostOpts)
-	FocusLine()
+	FocusLine(scrollIntoView bool)
 	HandleRender()
 	HandleRenderToMain()
 }
@@ -130,6 +131,7 @@ type IFilterableContext interface {
 	ReApplyFilter(bool)
 	IsFiltering() bool
 	IsFilterableContext()
+	FilterPrefix(tr *i18n.TranslationSet) string
 }
 
 type ISearchableContext interface {
@@ -180,6 +182,7 @@ type IListContext interface {
 	IsListContext() // used for type switch
 	RangeSelectEnabled() bool
 	RenderOnlyVisibleLines() bool
+	SetNeedRerenderVisibleLines()
 
 	IndexForGotoBottom() int
 }
@@ -199,12 +202,11 @@ type IPatchExplorerContext interface {
 }
 
 type IViewTrait interface {
-	FocusPoint(yIdx int)
+	FocusPoint(yIdx int, scrollIntoView bool)
 	SetRangeSelectStart(yIdx int)
 	CancelRangeSelect()
 	SetViewPortContent(content string)
-	SetViewPortContentAndClearEverythingElse(content string)
-	SetContentLineCount(lineCount int)
+	SetViewPortContentAndClearEverythingElse(lineCount int, content string)
 	SetContent(content string)
 	SetFooter(value string)
 	SetOriginX(value int)
@@ -219,8 +221,9 @@ type IViewTrait interface {
 }
 
 type OnFocusOpts struct {
-	ClickedWindowName  string
-	ClickedViewLineIdx int
+	ClickedWindowName       string
+	ClickedViewLineIdx      int
+	ScrollSelectionIntoView bool
 }
 
 type OnFocusLostOpts struct {
