@@ -7,7 +7,7 @@ import (
 
 var Revert = NewIntegrationTest(NewIntegrationTestArgs{
 	Description:  "Reverts a commit",
-	ExtraCmdArgs: "",
+	ExtraCmdArgs: []string{},
 	Skip:         false,
 	SetupConfig:  func(config *config.AppConfig) {},
 	SetupRepo: func(shell *Shell) {
@@ -29,9 +29,13 @@ var Revert = NewIntegrationTest(NewIntegrationTestArgs{
 					Confirm()
 			}).
 			Lines(
-				Contains("Revert \"first commit\"").IsSelected(),
-				Contains("first commit"),
-			)
+				Contains("Revert \"first commit\""),
+				Contains("first commit").IsSelected(),
+			).
+			Tap(func() {
+				t.Views().Main().Content(Contains("+myfile content"))
+			}).
+			SelectPreviousItem()
 
 		t.Views().Main().Content(Contains("-myfile content"))
 		t.FileSystem().PathNotPresent("myfile")
